import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import { CheckmarkCompactMIcon } from '@alfalab/icons-glyph/CheckmarkCompactMIcon';

var styles = {"component":"checkbox__component_c09y2","start":"checkbox__start_c09y2","center":"checkbox__center_c09y2","addons":"checkbox__addons_c09y2","block":"checkbox__block_c09y2","box":"checkbox__box_c09y2","checkedIcon":"checkbox__checkedIcon_c09y2","s":"checkbox__s_c09y2","disabled":"checkbox__disabled_c09y2","inactive":"checkbox__inactive_c09y2","checked":"checkbox__checked_c09y2","indeterminate":"checkbox__indeterminate_c09y2","label":"checkbox__label_c09y2","hint":"checkbox__hint_c09y2","focused":"checkbox__focused_c09y2","content":"checkbox__content_c09y2","errorMessage":"checkbox__errorMessage_c09y2","indeterminateLine":"checkbox__indeterminateLine_c09y2"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, size = 's', boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, error, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, styles[size], styles[align], className, {
            [styles.disabled]: disabled,
            [styles.inactive]: inactive,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId }, restProps)),
        React.createElement("span", { className: cn(styles.box, boxClassName) },
            checked && React.createElement(CheckmarkCompactMIcon, { className: styles.checkedIcon }),
            indeterminate && !checked && React.createElement("span", { className: styles.indeterminateLine })),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && React.createElement("span", { className: styles.label }, label),
            hint && !errorMessage && React.createElement("span", { className: styles.hint }, hint),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && React.createElement("span", { className: styles.addons }, addons)));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
